.. ParMOO documentation master file for the latex build

.. image:: img/logo-ParMOO.svg
    :align: center
    :alt: ParMOO

|

==========================================================================
ParMOO: Python library for parallel multiobjective simulation optimization
==========================================================================

User's Guide
============

.. toctree::
   :maxdepth: 3

   quickstart
   install
   about
   how-to-write
   extras
   jax-tips
   refs

API
===

.. toctree::
   :maxdepth: 3

   api

Tutorials
=========

.. toctree::
   :maxdepth: 3

   tutorials/basic-tutorials
   tutorials/libe-tutorial

Developer's Guide
=================

.. toctree::
   :maxdepth: 3

   dev-guide/contributing
   dev-guide/release-proc
   dev-guide/release-notes

Appendices
==========

.. toctree::
    :maxdepth: 3

    genindex
    modindex
